CustomCheckBox class

create_user: zhengzaihong email:1096877329@qq.com create_date: 2022/11/18 create_time: 10:29 describe: 复选框 eg:

Inheritance
Available extensions

Constructors

CustomCheckBox({Widget? text, Widget? checkedText, Widget? uncheckedIcon, Widget? checkIcon, MainAxisAlignment mainAxisAlignment = MainAxisAlignment.start, MainAxisSize mainAxisSize = MainAxisSize.max, CrossAxisAlignment crossAxisAlignment = CrossAxisAlignment.center, bool? useDefaultStyle = true, bool? iconLeft = false, bool? isChecked = false, dynamic onChange(bool value)?, bool enableFirstCallBack = false, Color? activeColor, Color? checkColor, double? scale = 1, WidgetStateProperty<Color?>? fillColor, BorderSide? side, double? splashRadius, Key? key})
const

Properties

activeColor → Color?
这色值针对 useDefaultStyle true 时生效
final
checkColor → Color?
final
checkedText → Widget?
final
checkIcon → Widget?
final
crossAxisAlignment → CrossAxisAlignment
final
enableFirstCallBack → bool
final
fillColor → WidgetStateProperty<Color?>?
final
hashCode → int
The hash code for this object.
no setterinherited
iconLeft → bool?
final
isChecked → bool?
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
mainAxisAlignment → MainAxisAlignment
final
mainAxisSize → MainAxisSize
final
onChange → dynamic Function(bool value)?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scale → double?
useDefaultStyle 为true时scale 生效
final
side → BorderSide?
final
splashRadius → double?
final
text → Widget?
final
uncheckedIcon → Widget?
final
useDefaultStyle → bool?
useDefaultStyle 为true 走系统默认样式,否则走自定义样式,外部传入
final

Methods

blurred({double blur = 5, Color blurColor = Colors.white, BorderRadius? borderRadius, double colorOpacity = 0.5, Widget? overlay, AlignmentGeometry alignment = Alignment.center}) → Blur

Available on Widget, provided by the BlurExtension extension

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<CustomCheckBox>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
frosted({double blur = 5, Color frostColor = Colors.white, AlignmentGeometry alignment = Alignment.center, double? height, double? width, double frostOpacity = 0.0, BorderRadius? borderRadius, EdgeInsetsGeometry padding = EdgeInsets.zero}) → Blur

Available on Widget, provided by the FrostExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited