InputValidation class

create_user: zhengzaihong email:1096877329@qq.com create_date: 2023/2/1 create_time: 17:52 describe: 输入框基础校验器,内置校验不满足时可继承该类或仿写校验规则

Constructors

InputValidation({bool? mustFill = true, int? minLength, int? maxLength, RegExp? regExp, String? errorMsg, String? format, String? emptyTip = "输入不能为空", List? formatValues = const []})
const

Properties

emptyTip → String?
final
errorMsg → String?
final
format → String?
final
formatValues → List?
final
hashCode → int
The hash code for this object.
no setterinherited
maxLength → int?
final
minLength → int?
final
mustFill → bool?
final
regExp → RegExp?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
validate(dynamic value) → String?

Operators

operator ==(Object other) → bool
The equality operator.
inherited