InputExtend<T> class

Inheritance
Available extensions

Constructors

InputExtend({required BuildSelectPop buildSelectPop, required OnChangeInput<String> onChanged, InputExtendController? controller, BuildCheckedBarStyle? buildCheckedBarStyle, FocusNode? focusNode, Duration duration = const Duration(milliseconds: 300), Curve curve = Curves.linear, double? checkedItemWidth = 60, double? checkedBarMaxWidth, double? checkedBarMinWidth, double? checkedBarMaxHeight, double? checkedBarMinHeight, TextStyle inputTextStyle = const TextStyle(color: Colors.black, fontSize: 16), OnCreate? onCreate, OnComplete? onComplete, InputDecorationStyle? inputDecoration, ScrollPhysics? physics, List<T>? initCheckedValue, int maxChecked = 100, bool enableClickClear = false, bool enableMultipleChoice = false, bool autoClose = false, bool enableHasFocusCallBack = false, bool barrierDismissible = true, PopBox? popBox, double selectPopMarginTop = 0, TextEditingController? textEditingController, ScrollController? inputScrollController, ScrollController? scrollController, TextInputType? keyboardType, TextInputAction? textInputAction, TextCapitalization textCapitalization = TextCapitalization.none, StrutStyle? strutStyle, TextAlign textAlign = TextAlign.start, TextAlignVertical? textAlignVertical, TextDirection? textDirection, bool readOnly = false, EditableTextContextMenuBuilder? contextMenuBuilder, bool? showCursor, bool autofocus = false, String obscuringCharacter = '•', bool obscureText = false, bool autocorrect = true, SmartDashesType? smartDashesType, SmartQuotesType? smartQuotesType, bool enableSuggestions = true, int? maxLines = 1, int? minLines, bool expands = false, int? maxLength, MaxLengthEnforcement? maxLengthEnforcement, VoidCallback? onEditingComplete, InputValueChanged<String>? onSubmitted, AppPrivateCommandCallback? onAppPrivateCommand, List<TextInputFormatter>? inputFormatters, bool? enabled, double cursorWidth = 2.0, double? cursorHeight, Radius? cursorRadius, Color? cursorColor, Brightness? keyboardAppearance, EdgeInsets scrollPadding = const EdgeInsets.all(20.0), DragStartBehavior dragStartBehavior = DragStartBehavior.start, bool? enableInteractiveSelection, TextSelectionControls? selectionControls, GestureTapCallback? onTap, MouseCursor? mouseCursor, InputCounterWidgetBuilder? buildCounter, ScrollPhysics? scrollPhysics, Iterable<String>? autofillHints = const <String>[], Clip clipBehavior = Clip.hardEdge, String? restorationId, bool scribbleEnabled = true, bool enableIMEPersonalizedLearning = true, double? popElevation = 0.0, Color? popColor = Colors.transparent, Color? popShadowColor, Color? popSurfaceTintColor, TextStyle? popChildTextStyle, BorderRadiusGeometry? popBorderRadius, ShapeBorder? popShape, Key? key})
const

Properties

autoClose → bool
选中后是否自动关闭下拉
final
autocorrect → bool
final
autofillHints → Iterable<String>?
final
autofocus → bool
final
barrierDismissible → bool
点击非遮罩层是否关闭
final
buildCheckedBarStyle → BuildCheckedBarStyle?
自定义选中后样式
final
buildCounter → InputCounterWidgetBuilder?
final
buildSelectPop → BuildSelectPop
自定义构建弹出窗样式
final
checkedBarMaxHeight → double?
final
checkedBarMaxWidth → double?
final
checkedBarMinHeight → double?
final
checkedBarMinWidth → double?
final
checkedItemWidth → double?
已选择的显示项宽度
final
clipBehavior → Clip
final
contextMenuBuilder → EditableTextContextMenuBuilder?
final
controller → InputExtendController?
final
cursorColor → Color?
final
cursorHeight → double?
final
cursorRadius → Radius?
final
cursorWidth → double
final
curve → Curve
final
dragStartBehavior → DragStartBehavior
final
duration → Duration
final
enableClickClear → bool
是否启用 自动清除输入框中内容(在下拉选择后)
final
enabled → bool?
final
enableHasFocusCallBack → bool
输入框得到焦点即回调。
final
enableIMEPersonalizedLearning → bool
final
enableInteractiveSelection → bool?
final
enableMultipleChoice → bool
是否允许多选
final
enableSuggestions → bool
final
expands → bool
final
focusNode → FocusNode?
final
hashCode → int
The hash code for this object.
no setterinherited
initCheckedValue → List<T>?
输入框中的初始数据
final
inputDecoration → InputDecorationStyle?
输入框的背景样式
final
inputFormatters → List<TextInputFormatter>?
final
inputScrollController → ScrollController?
final
inputTextStyle → TextStyle
输入文本样式
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
keyboardAppearance → Brightness?
final
keyboardType → TextInputType?
以下都为输入框的样式 属性
final
maxChecked → int
支持的最大选择数量
final
maxLength → int?
final
maxLengthEnforcement → MaxLengthEnforcement?
final
maxLines → int?
final
minLines → int?
final
mouseCursor → MouseCursor?
final
obscureText → bool
final
obscuringCharacter → String
final
onAppPrivateCommand → AppPrivateCommandCallback?
final
onChanged → OnChangeInput<String>
数据发生变化时的回调
final
onComplete → OnComplete?
创建完成
final
onCreate → OnComplete?
开始创建
final
onEditingComplete → OnComplete?
final
onSubmitted → InputValueChanged<String>?
final
onTap → OnComplete?
final
physics → ScrollPhysics?
final
popBorderRadius → BorderRadiusGeometry?
final
popBox → PopBox?
final
popChildTextStyle → TextStyle?
final
popColor → Color?
final
popElevation → double?
final
popShadowColor → Color?
final
popShape → ShapeBorder?
final
popSurfaceTintColor → Color?
final
readOnly → bool
final
restorationId → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scribbleEnabled → bool
final
scrollController → ScrollController?
final
scrollPadding → EdgeInsets
final
scrollPhysics → ScrollPhysics?
final
selectionControls → TextSelectionControls?
final
selectPopMarginTop → double
final
showCursor → bool?
final
smartDashesType → SmartDashesType?
final
smartQuotesType → SmartQuotesType?
final
strutStyle → StrutStyle?
final
textAlign → TextAlign
final
textAlignVertical → TextAlignVertical?
final
textCapitalization → TextCapitalization
final
textDirection → TextDirection?
final
textEditingController → TextEditingController?
final
textInputAction → TextInputAction?
final

Methods

blurred({double blur = 5, Color blurColor = Colors.white, BorderRadius? borderRadius, double colorOpacity = 0.5, Widget? overlay, AlignmentGeometry alignment = Alignment.center}) → Blur

Available on Widget, provided by the BlurExtension extension

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → InputExtendState
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
frosted({double blur = 5, Color frostColor = Colors.white, AlignmentGeometry alignment = Alignment.center, double? height, double? width, double frostOpacity = 0.0, BorderRadius? borderRadius, EdgeInsetsGeometry padding = EdgeInsets.zero}) → Blur

Available on Widget, provided by the FrostExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited