TimeViewController class

Constructors

TimeViewController()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state → TimeViewState?
no setter

Methods

bind(TimeViewState state) → void
cancelTimer() → void
dispose() → void
getRenderBox() → RenderBox?
isStart() → bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
startTimer() → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited