CycleProgressBar class

Inheritance
Available extensions

Constructors

CycleProgressBar({Key? key, double percent = 0.0, double lineWidth = 5.0, double startAngle = 0.0, required double radius, Color fillColor = Colors.transparent, Color backgroundColor = const Color(0xFFB8C7CB), Color? progressColor, double backgroundWidth = -1, LinearGradient? linearGradient, bool animation = false, int animationDuration = 500, Widget? header, Widget? footer, Widget? center, bool addAutomaticKeepAlive = true, CircularStrokeCap circularStrokeCap = CircularStrokeCap.butt, Color? arcBackgroundColor, ArcType? arcType, bool animateFromLastPercent = false, bool reverse = false, Curve curve = Curves.linear, MaskFilter? maskFilter, bool restartAnimation = false, VoidCallback? onAnimationEnd, Widget? widgetIndicator, bool rotateLinearGradient = false, Color? progressBorderColor})

Properties

addAutomaticKeepAlive → bool
final
animateFromLastPercent → bool
final
animation → bool
是否开启动画
final
animationDuration → int
动画时长 milliseconds
final
arcBackgroundColor → Color?
final
arcType → ArcType?
final
backgroundColor → Color
背景颜色
final
backgroundWidth → double
未填充的bar 宽度
final
center → Widget?
final
circularStrokeCap → CircularStrokeCap
final
curve → Curve
final
fillColor → Color
填充进度颜色
final
final
hashCode → int
The hash code for this object.
no setterinherited
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
linearGradient → LinearGradient?
final
lineWidth → double
bar 的宽度
final
maskFilter → MaskFilter?
final
onAnimationEnd → VoidCallback?
final
percent → double
百分比进度 0-1
final
progressBorderColor → Color?
进度边框颜色
final
progressColor → Color
no setter
radius → double
final
restartAnimation → bool
final
reverse → bool
final
rotateLinearGradient → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startAngle → double
final
widgetIndicator → Widget?
final

Methods

blurred({double blur = 5, Color blurColor = Colors.white, BorderRadius? borderRadius, double colorOpacity = 0.5, Widget? overlay, AlignmentGeometry alignment = Alignment.center}) → Blur

Available on Widget, provided by the BlurExtension extension

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → _CycleProgressBarState
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
frosted({double blur = 5, Color frostColor = Colors.white, AlignmentGeometry alignment = Alignment.center, double? height, double? width, double frostOpacity = 0.0, BorderRadius? borderRadius, EdgeInsetsGeometry padding = EdgeInsets.zero}) → Blur

Available on Widget, provided by the FrostExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited