LinearProgressBar class

Inheritance
Available extensions

Constructors

LinearProgressBar({Key? key, Color fillColor = Colors.transparent, double percent = 0.0, double lineHeight = 5.0, double? width, Color? backgroundColor, LinearGradient? linearGradientBackgroundColor, LinearGradient? linearGradient, Color? progressColor, bool animation = false, int animationDuration = 500, bool animateFromLastPercent = false, bool isRTL = false, Widget? leading, Widget? trailing, Widget? center, bool addAutomaticKeepAlive = true, Radius? barRadius, EdgeInsets padding = const EdgeInsets.symmetric(horizontal: 10.0), MainAxisAlignment alignment = MainAxisAlignment.start, MaskFilter? maskFilter, bool clipLinearGradient = false, Curve curve = Curves.linear, bool restartAnimation = false, VoidCallback? onAnimationEnd, Widget? widgetIndicator, Color? progressBorderColor})

Properties

addAutomaticKeepAlive → bool
final
alignment → MainAxisAlignment
final
animateFromLastPercent → bool
final
animation → bool
是否开启动画
final
animationDuration → int
动画时长 milliseconds
final
backgroundColor → Color
背景色
no setter
barRadius → Radius?
final
center → Widget?
final
clipLinearGradient → bool
final
curve → Curve
final
fillColor → Color
填充颜色
final
hashCode → int
The hash code for this object.
no setterinherited
isRTL → bool
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
leading → Widget?
final
linearGradient → LinearGradient?
final
linearGradientBackgroundColor → LinearGradient?
线性渐变
final
lineHeight → double
高度
final
maskFilter → MaskFilter?
final
onAnimationEnd → VoidCallback?
final
padding → EdgeInsets
final
percent → double
百分比进度 0-1
final
progressBorderColor → Color?
边框颜色 进度
final
progressColor → Color
no setter
restartAnimation → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
trailing → Widget?
final
widgetIndicator → Widget?
final
width → double?
final

Methods

blurred({double blur = 5, Color blurColor = Colors.white, BorderRadius? borderRadius, double colorOpacity = 0.5, Widget? overlay, AlignmentGeometry alignment = Alignment.center}) → Blur

Available on Widget, provided by the BlurExtension extension

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → _LinearProgressBarState
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
frosted({double blur = 5, Color frostColor = Colors.white, AlignmentGeometry alignment = Alignment.center, double? height, double? width, double frostOpacity = 0.0, BorderRadius? borderRadius, EdgeInsetsGeometry padding = EdgeInsets.zero}) → Blur

Available on Widget, provided by the FrostExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited