SelectionMenuFormController class

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

bind(SelectionMenuFormState state) → void
closePop() → void
dispose() → void
getRenderBox() → RenderBox?
getState() → SelectionMenuFormState?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
refresh() → void
toString() → String
A string representation of this object.
inherited
validator() → void

Operators

operator ==(Object other) → bool
The equality operator.
inherited