CustomSwitch class

create_user: zhengzaihong email:1096877329@qq.com create_date: 2022/11/17 create_time: 17:44 describe: 开关按钮组件, 支持ios风格和android风格 需自定义各种样式和效果请使用提供的 ImageSwitch 组件 eg:

Inheritance
Available extensions

Constructors

CustomSwitch({bool isOpen = true, ValueChanged<bool>? onChange, bool labelRight = false, bool? isInnerStyle = false, Widget label = const SizedBox(), bool? enableFirstCallBack = false, double? margin = 0, double scale = 1, Color? activeColor, Color? activeTrackColor, Color? inactiveThumbColor, Color? inactiveTrackColor, Key? key})
const

Properties

activeColor → Color?
final
activeTrackColor → Color?
final
enableFirstCallBack → bool?
final
hashCode → int
The hash code for this object.
no setterinherited
inactiveThumbColor → Color?
final
inactiveTrackColor → Color?
final
isInnerStyle → bool?
开关的样式 true内含样式ios 风格, false滑动模块外突android风格
final
isOpen → bool
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
label → Widget
final
labelRight → bool
final
margin → double?
final
onChange → ValueChanged<bool>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scale → double
final

Methods

blurred({double blur = 5, Color blurColor = Colors.white, BorderRadius? borderRadius, double colorOpacity = 0.5, Widget? overlay, AlignmentGeometry alignment = Alignment.center}) → Blur

Available on Widget, provided by the BlurExtension extension

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<CustomSwitch>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
frosted({double blur = 5, Color frostColor = Colors.white, AlignmentGeometry alignment = Alignment.center, double? height, double? width, double frostOpacity = 0.0, BorderRadius? borderRadius, EdgeInsetsGeometry padding = EdgeInsets.zero}) → Blur

Available on Widget, provided by the FrostExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited