TableView<T> class

create_user: zhengzaihong email:1096877329@qq.com create_date: 2022/6/20 create_time: 9:51 describe: 绘制表格的组件,使用此组件一定要注意每行的权重比 此组件用于通用性表格, 表格存在各种合并的单元格 需根据行号单独处理 需要水平和垂直方向都可滑动的表格 使用 TableViewExtend 实现, TableView 不在支持双向滑动,仅垂直滑动的表格

Inheritance
Available extensions

Constructors

TableView({List<T>? tableDatas = const [], required BuildRowStyle buildRowStyle, bool enableTopDivider = false, bool enableBottomDivider = false, bool enableDivider = false, PreDealData? preDealData, bool shrinkWrap = true, Color dividerColor = Colors.black, double dividerHeight = 1, Axis scrollDirection = Axis.vertical, bool reverse = false, ScrollController? controller, ScrollPhysics? physics, EdgeInsetsGeometry? padding, bool addAutomaticKeepAlive = true, bool addRepaintBoundaries = true, bool addSemanticIndexes = true, double? cacheExtent, Key? key})
const

Properties

addAutomaticKeepAlive → bool
final
addRepaintBoundaries → bool
final
addSemanticIndexes → bool
final
buildRowStyle → BuildRowStyle
构建每一行的回调
final
cacheExtent → double?
final
controller → ScrollController?
final
dividerColor → Color
纵向分割线 横向分割线在 TabRow配置
final
dividerHeight → double
final
enableBottomDivider → bool
是否开启 尾部分割线
final
enableDivider → bool
final
enableTopDivider → bool
是否开启 顶部分割线
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
padding → EdgeInsetsGeometry?
final
physics → ScrollPhysics?
final
preDealData → PreDealData?
添加此回调 会覆盖 tableDatas 数据
final
reverse → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scrollDirection → Axis
final
shrinkWrap → bool
final
tableDatas → List<T>?
数据 表示表格有多少行
final

Methods

blurred({double blur = 5, Color blurColor = Colors.white, BorderRadius? borderRadius, double colorOpacity = 0.5, Widget? overlay, AlignmentGeometry alignment = Alignment.center}) → Blur

Available on Widget, provided by the BlurExtension extension

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<TableView>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
frosted({double blur = 5, Color frostColor = Colors.white, AlignmentGeometry alignment = Alignment.center, double? height, double? width, double frostOpacity = 0.0, BorderRadius? borderRadius, EdgeInsetsGeometry padding = EdgeInsets.zero}) → Blur

Available on Widget, provided by the FrostExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited