TextExtend class

Inheritance
Available extensions

Constructors

TextExtend({String? text, ValueChanged<bool>? onHover, bool canOnHover = true, TextStyle? style, TextStyle? onHoverStyle, bool isSelectable = false, Widget? suffix, Widget? prefix, Widget? onHoverSuffix, Widget? onHoverPrefix, int? maxLength, double? width, double? height, BuilderChild? builder, CustomChildLayout? customChildLayout, bool animation = false, Duration animationTime = const Duration(milliseconds: 150), Offset startOffset = const Offset(0, 0), Offset endOffset = const Offset(0, -10), MainAxisAlignment mainAxisAlignment = MainAxisAlignment.start, MainAxisSize mainAxisSize = MainAxisSize.max, CrossAxisAlignment crossAxisAlignment = CrossAxisAlignment.center, TextDirection? textDirection, VerticalDirection verticalDirection = VerticalDirection.down, Locale? locale, bool? softWrap, TextOverflow? overflow, int? maxLines, String? semanticsLabel, TextWidthBasis? textWidthBasis, TextAlign? textAlign, TextBaseline? textBaseline, AlignmentGeometry? alignment, EdgeInsetsGeometry? padding, Color? color, Decoration? decoration, Decoration? foregroundDecoration, BoxConstraints? constraints, EdgeInsetsGeometry? margin, Matrix4? transform, AlignmentGeometry? transformAlignment, AlignmentGeometry? onHoverAlignment, EdgeInsetsGeometry? onHoverPadding, Color? onHoverColor, Decoration? onHoverDecoration, Decoration? onHoverForegroundDecoration, BoxConstraints? onHoverConstraints, EdgeInsetsGeometry? onHoverMargin, Matrix4? onHoverTransform, AlignmentGeometry? onHoverTransformAlignment, GestureTapCallback? onTap, GestureTapDownCallback? onTapDown, GestureTapUpCallback? onTapUp, GestureTapCallback? onTapCancel, GestureTapCallback? onDoubleTap, GestureLongPressCallback? onLongPress, GestureTapCallback? onSecondaryTap, GestureTapDownCallback? onSecondaryTapDown, GestureTapUpCallback? onSecondaryTapUp, GestureTapCallback? onSecondaryTapCancel, ValueChanged<bool>? onHighlightChanged, MouseCursor? mouseCursor, bool containedInkWell = false, BoxShape highlightShape = BoxShape.circle, double? radius, BorderRadius? borderRadius, ShapeBorder? customBorder, Color? focusColor, Color? hoverColor, Color? highlightColor, WidgetStateProperty<Color?>? overlayColor, Color? splashColor, InteractiveInkFeatureFactory? splashFactory, bool enableFeedback = true, bool excludeFromSemantics = false, FocusNode? focusNode, bool canRequestFocus = true, ValueChanged<bool>? onFocusChange, bool autofocus = false, Key? key})
const

Properties

alignment → AlignmentGeometry?
final
animation → bool
final
animationTime → Duration
final
autofocus → bool
final
borderRadius → BorderRadius?
final
builder → BuilderChild?
final
canOnHover → bool
final
canRequestFocus → bool
final
color → Color?
final
constraints → BoxConstraints?
final
containedInkWell → bool
final
crossAxisAlignment → CrossAxisAlignment
final
customBorder → ShapeBorder?
final
customChildLayout → CustomChildLayout?
final
decoration → Decoration?
final
enableFeedback → bool
final
endOffset → Offset
final
excludeFromSemantics → bool
final
focusColor → Color?
final
focusNode → FocusNode?
final
foregroundDecoration → Decoration?
final
hashCode → int
The hash code for this object.
no setterinherited
height → double?
final
highlightColor → Color?
final
highlightShape → BoxShape
final
hoverColor → Color?
final
isSelectable → bool
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
locale → Locale?
final
mainAxisAlignment → MainAxisAlignment
final
mainAxisSize → MainAxisSize
final
margin → EdgeInsetsGeometry?
final
maxLength → int?
final
maxLines → int?
final
mouseCursor → MouseCursor?
final
onDoubleTap → GestureTapCallback?
final
onFocusChange → ValueChanged<bool>?
final
onHighlightChanged → ValueChanged<bool>?
final
onHover → ValueChanged<bool>?
final
onHoverAlignment → AlignmentGeometry?
final
onHoverColor → Color?
final
onHoverConstraints → BoxConstraints?
final
onHoverDecoration → Decoration?
final
onHoverForegroundDecoration → Decoration?
final
onHoverMargin → EdgeInsetsGeometry?
final
onHoverPadding → EdgeInsetsGeometry?
final
onHoverPrefix → Widget?
final
onHoverStyle → TextStyle?
final
onHoverSuffix → Widget?
final
onHoverTransform → Matrix4?
final
onHoverTransformAlignment → AlignmentGeometry?
final
onLongPress → GestureTapCallback?
final
onSecondaryTap → GestureTapCallback?
final
onSecondaryTapCancel → GestureTapCallback?
final
onSecondaryTapDown → GestureTapDownCallback?
final
onSecondaryTapUp → GestureTapUpCallback?
final
onTap → GestureTapCallback?
final
onTapCancel → GestureTapCallback?
final
onTapDown → GestureTapDownCallback?
final
onTapUp → GestureTapUpCallback?
final
overflow → TextOverflow?
final
overlayColor → WidgetStateProperty<Color?>?
final
padding → EdgeInsetsGeometry?
final
prefix → Widget?
final
radius → double?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
semanticsLabel → String?
final
softWrap → bool?
final
splashColor → Color?
final
splashFactory → InteractiveInkFeatureFactory?
final
startOffset → Offset
final
style → TextStyle?
final
suffix → Widget?
final
text → String?
final
textAlign → TextAlign?
final
textBaseline → TextBaseline?
final
textDirection → TextDirection?
final
textWidthBasis → TextWidthBasis?
final
transform → Matrix4?
final
transformAlignment → AlignmentGeometry?
final
verticalDirection → VerticalDirection
final
width → double?
final

Methods

blurred({double blur = 5, Color blurColor = Colors.white, BorderRadius? borderRadius, double colorOpacity = 0.5, Widget? overlay, AlignmentGeometry alignment = Alignment.center}) → Blur

Available on Widget, provided by the BlurExtension extension

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<TextExtend>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
frosted({double blur = 5, Color frostColor = Colors.white, AlignmentGeometry alignment = Alignment.center, double? height, double? width, double frostOpacity = 0.0, BorderRadius? borderRadius, EdgeInsetsGeometry padding = EdgeInsets.zero}) → Blur

Available on Widget, provided by the FrostExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited