TextView class

create_user: zhengzaihong email:1096877329@qq.com create_date: 2022/6/12 create_time: 17:23 describe: 上下左右支持 icon的Widget

Inheritance
Available extensions

Constructors

TextView({required String title, TextStyle checkedTextStyle = const TextStyle(color: Colors.white, fontSize: 20), TextStyle unCheckTextStyle = const TextStyle(color: Colors.black38, fontSize: 20), Color highlightColor = Colors.transparent, Color hoverColor = Colors.transparent, double drawPadding = 5.0, PositionEnum drawablePosition = PositionEnum.drawableRight, Widget? drawableWidget, Widget? drawablePressWidget, bool enableClick = true, bool isChecked = true, dynamic callBack(bool checked)?, StrutStyle? strutStyle, TextAlign? textAlign, TextDirection? textDirection, Locale? locale, bool? softWrap, TextOverflow? overflow, TextScaler? textScaler, int? maxLines, String? semanticsLabel, CrossAxisAlignment crossAxisAlignment = CrossAxisAlignment.center, MainAxisAlignment mainAxisAlignment = MainAxisAlignment.start, MainAxisSize mainAxisSize = MainAxisSize.min, Key? key})
const

Properties

callBack → dynamic Function(bool checked)?
final
checkedTextStyle → TextStyle
final
crossAxisAlignment → CrossAxisAlignment
final
drawablePosition → PositionEnum
图标显示位置
final
drawablePressWidget → Widget?
final
drawableWidget → Widget?
通常设置的图标 (选中和未选中支持)
final
drawPadding → double
final
enableClick → bool
是否可点击
final
hashCode → int
The hash code for this object.
no setterinherited
highlightColor → Color
final
hoverColor → Color
final
isChecked → bool
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
locale → Locale?
final
mainAxisAlignment → MainAxisAlignment
final
mainAxisSize → MainAxisSize
final
maxLines → int?
final
overflow → TextOverflow?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
semanticsLabel → String?
final
softWrap → bool?
final
strutStyle → StrutStyle?
final
textAlign → TextAlign?
final
textDirection → TextDirection?
final
textScaler → TextScaler?
final
title → String
final
unCheckTextStyle → TextStyle
final

Methods

blurred({double blur = 5, Color blurColor = Colors.white, BorderRadius? borderRadius, double colorOpacity = 0.5, Widget? overlay, AlignmentGeometry alignment = Alignment.center}) → Blur

Available on Widget, provided by the BlurExtension extension

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → _TextViewState
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
frosted({double blur = 5, Color frostColor = Colors.white, AlignmentGeometry alignment = Alignment.center, double? height, double? width, double frostOpacity = 0.0, BorderRadius? borderRadius, EdgeInsetsGeometry padding = EdgeInsets.zero}) → Blur

Available on Widget, provided by the FrostExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited