NumUtils class

create_user: zhengzaihong email:1096877329@qq.com create_date: 2024/4/12 create_time: 9:59 describe: 数字转化工具

Constructors

NumUtils()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

getNumByValueDouble(double? value, int fractionDigits) → num?
fractionDigits == 0-20
getNumByValueStr(String valueStr, {int? fractionDigits}) → num?
fractionDigits == 0-20
nilToDef(num? value, num def) → num