StringUtils class

create_user: zhengzaihong email:1096877329@qq.com create_date: 2022/7/4 create_time: 17:34 describe: 文本处理工具

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

equals(String? a, String? b) → bool
fts(String? a, String? b) → String
hasAz(String str) → bool
【含有英文】true
hasNum(String str) → bool
【含有数字】true
isAz(String str) → bool
【全为英文】返回true 否则false
isAzNum(String str) → bool
【除英文和数字外无其他字符(只有英文数字的字符串)】返回true 否则false
isChinese(String str) → bool
判断是否为纯中文,不是返回false
isEmpty(String? string) → bool
检查字符串是否空
isEmptyInList(List<String?> list) → bool
isEmptyObj(Object? obj) → bool
isNotEmpty(String? string) → bool
isNum(String str) → bool
【全为数字】返回true
nilToDef(String? value, String def, {String? suffix, bool defSuffix = false}) → String